#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-2ANZ9UeCZiJG9ZGrfFAS5t
key:                  mustache-2.4.3.1-2ANZ9UeCZiJG9ZGrfFAS5t
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  6da5ebb439d70b9c0dbebc0a99b44e42
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-2ANZ9UeCZiJG9ZGrfFAS5t
depends:
    aeson-2.2.1.0-BfV39Vpjeh9G4TP9CsFVxm base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 parsec-3.1.16.1
    scientific-0.3.8.1-DLJUsVzfkt8S4sgDRE9je template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

